import React, { useState, useRef, useEffect } from 'react'
import { useTranslation } from 'react-i18next'

import { Box, Button } from '@mui/material'
import Page from 'components/page'

import { useHistory } from 'react-router-dom'
import OverviewGuestButton from '../../components/overviewGuestButton'
import GuestRegisterStep from './registerPage'
import { GuestRegisterCallableMethods } from './guestRegisterCallableMethods'
import { EnteredGuestData } from './enteredGuestData'
import { ContactInformationBySponsor } from './guestDataForm'


/*
 * When the guest reaches this page he has already an invite ID set in his session.
 */
export default function GuestRegister() {
  const { t } = useTranslation(['common'])
  const history = useHistory()
  const [guestFormData, setGuestFormData] = useState<ContactInformationBySponsor>({
    first_name: '',
    last_name: '',
    ou_name_en: '',
    ou_name_nb: '',
    role_name_en: '',
    role_name_nb: '',
    role_start: '',
    role_end: '',
    comment: undefined,
  })

  const guestContactInfo = async () => {
    const response = await fetch('/api/ui/v1/invited')

    if (response.ok) {
      response.json().then(jsonResponse => {
        setGuestFormData({
          first_name: jsonResponse.person.first_name,
          last_name: jsonResponse.person.last_name,
          ou_name_en: jsonResponse.role.ou_name_en,
          ou_name_nb: jsonResponse.role.ou_name_nb,
          role_name_en: jsonResponse.role.role_name_en,
          role_name_nb: jsonResponse.role.role_name_nb,
          role_start: jsonResponse.role.start,
          role_end: jsonResponse.role.end,
          comment: jsonResponse.role.comments,
        })
      })
    }
  }


  useEffect(() => {
    guestContactInfo()
  }, [])

  const guestRegisterRef = useRef<GuestRegisterCallableMethods>(null)

  const REGISTER_STEP = 0
  const [activeStep, setActiveStep] = useState(0)

  const handleNext = () => {
    if (activeStep === 0) {
      if (guestRegisterRef.current) {
        guestRegisterRef.current.doSubmit()
      }
    }
  }

  const handleForwardFromRegister = (
    updateFormData: EnteredGuestData,
  ): void => {
    // TODO Go to consent page
    // setActiveStep((prevActiveStep) => prevActiveStep + 1)
  }

  const handleCancel = () => {
    history.push('/')
  }


  return (
    <Page>
      <OverviewGuestButton />
      {/* Current page in wizard */}
      <Box sx={{ width: '100%' }}>
        {activeStep === REGISTER_STEP && (
          <GuestRegisterStep
            nextHandler={handleForwardFromRegister}
            guestData={guestFormData}
            ref={guestRegisterRef}
          />
        )}
      </Box>

      <Box sx={{ display: 'flex', flexDirection: 'row', pt: 2, color: 'primary.main', paddingBottom: '1rem' }}>
        {activeStep === REGISTER_STEP && (
          <Button data-testid='button-next'
                  sx={{ color: 'theme.palette.secondary', mr: 1 }}
                  onClick={handleNext}>
            {t('button.next')}
          </Button>
        )}

        <Button
          onClick={handleCancel}
        >
          {t('button.cancel')}
        </Button>
      </Box>
    </Page>
  )
}
