import {
  getCookie,
  isValidEmail,
  isValidFnr,
  isValidMobilePhoneNumber,
  maybeCsrfToken,
  postJsonOpts,
} from './index'

// Mock i18next module to return a translation that just returns the key
jest.mock('i18next', () => ({
  t: (value: string) => value,
}))

test('Invalid phone number', async () => {
  expect(isValidMobilePhoneNumber('dafasfdsfasdf')).not.toEqual(true)
})

test('Empty mobile phone number', async () => {
  expect(isValidMobilePhoneNumber(undefined)).not.toEqual(true)
})

test('Valid phone number', async () => {
  expect(isValidMobilePhoneNumber('+47 97510000')).toEqual(true)
})

test('Valid e-mail', async () => {
  expect(isValidEmail('test@example.org')).toEqual(true)
  expect(isValidEmail('Test.Tester@example.org')).toEqual(true)
})

test('Invalid e-mail', async () => {
  expect(isValidEmail('testexample.org')).not.toEqual(true)
  expect(isValidEmail('test')).not.toEqual(true)
  // Treat special characters as invalid, some services allow them though
  expect(isValidEmail('Øyvind.Åsen@example.org')).not.toEqual(true)
  expect(isValidEmail('Test.Tester@åsen.org')).not.toEqual(true)
})

test('Body has values', async () => {
  const data = { foo: 'bar' }
  expect(postJsonOpts(data)).toEqual({
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
    },
    body: '{"foo":"bar"}',
    credentials: 'same-origin',
  })
})

test('Get cookie when set', async () => {
  document.cookie = 'csrftoken=tokenvalue'
  expect(maybeCsrfToken()).toEqual({ 'X-CSRFToken': 'tokenvalue' })
  document.cookie = 'csrftoken= ; expires = Thu, 01 Jan 1970 00:00:00 GMT'
})

test('Get null if cookie not set', async () => {
  expect(maybeCsrfToken()).toEqual(null)
})

test('Get unknown cookie returns null', async () => {
  document.cookie = 'csrftoken=tokenvalue'
  expect(getCookie('foo')).toEqual(null)
  document.cookie = 'csrftoken= ; expires = Thu, 01 Jan 1970 00:00:00 GMT'
})

test('Valid fnr', async () => {
  expect(isValidFnr('04026514903')).toEqual(true)
})

test('Null fnr', async () => {
  expect(isValidFnr(undefined)).toEqual('common:validation.invalidIdNumber')
})

test('Invalid fnr', async () => {
  expect(isValidFnr('')).toEqual('common:validation.invalidIdNumber')
})
